@@ -9,6 +9,6 @@ log = Logger("Test logger")
 
 def run():
     f = NamedTemporaryFile()
-    with FileHandler(f.name) as handler:
-        for x in range(500):
+    with FileHandler(f.name):
+        for _ in range(500):
             log.warning("this is handled")
