@@ -1,4 +1,5 @@
 """Tests with a logging handler becoming a noop for comparison"""
+
 from io import StringIO
 from logging import ERROR, StreamHandler, getLogger
 
@@ -10,5 +11,5 @@ def run():
     out = StringIO()
     handler = StreamHandler(out)
     log.addHandler(handler)
-    for x in range(500):
+    for _ in range(500):
         log.warning("this is not handled")
