@@ -1,4 +1,5 @@
 """Tests redirects from logging to logbook"""
+
 from io import StringIO
 from logging import getLogger
 
@@ -12,6 +13,6 @@ log = getLogger("Test logger")
 def run():
     out = StringIO()
     with StreamHandler(out):
-        for x in range(500):
+        for _ in range(500):
             log.warning("this is not handled")
     assert out.getvalue().count("\n") == 500
