@@ -6,6 +6,6 @@ log = Logger("Test logger")
 
 
 def run():
-    with TestHandler() as handler:
-        for x in range(500):
+    with TestHandler():
+        for _ in range(500):
             log.warning("this is not handled")
